==> haskell-non-negative-0.1.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.1.2
id: non-negative-0.1.1.2-978XXC1oNssEJaybMovel8
key: non-negative-0.1.1.2-978XXC1oNssEJaybMovel8
license: GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
abi: e44653168eddd6090df50c770155ba10
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/non-negative-0.1.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/non-negative-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/non-negative-0.1.1.2
hs-libraries: HSnon-negative-0.1.1.2-978XXC1oNssEJaybMovel8
depends:
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l base-4.10.1.0
abi-depends: utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=a871331a7e5e7b5c37818b7997512ddd
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.1.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.1.2
id: non-negative-0.1.1.2-KGx4UZT49l6H0Y0D8s8xRu
key: non-negative-0.1.1.2-KGx4UZT49l6H0Y0D8s8xRu
license: GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
abi: 674e458999f460d07b55c5fb3d8e590b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/non-negative-0.1.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/non-negative-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/non-negative-0.1.1.2
hs-libraries: HSnon-negative-0.1.1.2-KGx4UZT49l6H0Y0D8s8xRu
depends:
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
abi-depends: utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
